@@ -57,8 +57,8 @@ import com.sencha.gxt.widget.core.client.form.TextField;
 
 /**
  * 
- * @author "Giancarlo Panichi" <a
- *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
+ * @author Giancarlo Panichi
+ *
  * 
  */
 public class ReplaceColumnByMultiColumnExpressionPanel extends FramedPanel {
@@ -71,10 +71,10 @@ public class ReplaceColumnByMultiColumnExpressionPanel extends FramedPanel {
 	private static final String PARENT_HEIGHT = "490px";
 	private static final String PARENT_HEIGHT_REDUCE = "404px";
 
-	private static final String CONDITIONWIDTH = "890px";
+	private static final String CONDITIONWIDTH = "900px";
 	private static final String CONDITIONHEIGHT = "120px";
-	private static final String CONDITION_LAYOUT_WIDTH = "890px";
-	private static final String REPLACEWIDTH = "894px";
+	private static final String CONDITION_LAYOUT_WIDTH = "900px";
+	private static final String REPLACEWIDTH = "904px";
 	private static final String REPLACEHEIGHT = "120px";
 	private static final String ALL_ROWS_FIELD_WIDTH = "884px";
 
@@ -298,11 +298,11 @@ public class ReplaceColumnByMultiColumnExpressionPanel extends FramedPanel {
 		// basicLayout.setScrollMode(ScrollMode.AUTO);
 
 		// Add to basic layout
-		basicLayout.add(properties, new VerticalLayoutData(-1, -1,
+		basicLayout.add(properties, new VerticalLayoutData(1, -1,
 				new Margins(1)));
-		basicLayout.add(conditionsFieldSet, new VerticalLayoutData(-1, -1,
+		basicLayout.add(conditionsFieldSet, new VerticalLayoutData(1, -1,
 				new Margins(1)));
-		basicLayout.add(replaceValueFieldSet, new VerticalLayoutData(-1, -1,
+		basicLayout.add(replaceValueFieldSet, new VerticalLayoutData(1, -1,
 				new Margins(1)));
 
 		basicLayout.add(flowButton, new VerticalLayoutData(1, 36, new Margins(
