@@ -30,6 +30,7 @@ import com.google.gwt.event.logical.shared.SelectionHandler;
 import com.google.gwt.user.client.rpc.AsyncCallback;
 import com.google.web.bindery.event.shared.EventBus;
 import com.sencha.gxt.cell.core.client.form.ComboBoxCell.TriggerAction;
+import com.sencha.gxt.core.client.dom.ScrollSupport.ScrollMode;
 import com.sencha.gxt.core.client.util.Margins;
 import com.sencha.gxt.data.shared.ListStore;
 import com.sencha.gxt.widget.core.client.container.BoxLayoutContainer.BoxLayoutData;
@@ -44,8 +45,8 @@ import com.sencha.gxt.widget.core.client.form.TextField;
 
 /**
  * 
- * @author "Giancarlo Panichi" <a
- *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
+ * @author Giancarlo Panichi
+ *
  * 
  */
 public class ReplaceWidget extends SimpleContainer {
@@ -271,8 +272,10 @@ public class ReplaceWidget extends SimpleContainer {
 		itemIdHoriz = "Horiz" + sign;
 
 		vert = new VerticalLayoutContainer();
-		// vert.setScrollMode(ScrollMode.AUTO); Set in GXT 3.0.1
-
+		vert.setScrollMode(ScrollMode.AUTO);// Set In GXT 3.0.1
+		vert.setAdjustForScroll(true);
+		
+		
 		final HBoxLayoutContainer horiz = new HBoxLayoutContainer();
 
 		final TextField firstArg = new TextField();
@@ -290,7 +293,7 @@ public class ReplaceWidget extends SimpleContainer {
 				propsColumnData.id());
 		Log.debug("Store Columns: " + storeColumns);
 		storeColumns.addAll(columns);
-
+		
 		final ComboBox<ColumnData> comboColumns = new ComboBox<ColumnData>(
 				storeColumns, propsColumnData.label());
 
@@ -596,7 +599,7 @@ public class ReplaceWidget extends SimpleContainer {
 		horiz.add(firstArg, new BoxLayoutData(new Margins(0)));
 		horiz.add(secondArg, new BoxLayoutData(new Margins(0)));
 		horiz.setItemId(itemIdHoriz);
-		vert.add(horiz, new VerticalLayoutData(-1, -1, new Margins(1)));
+		vert.add(horiz, new VerticalLayoutData(1, -1, new Margins(1)));
 
 		add(vert, new MarginData(0));
 
@@ -933,7 +936,7 @@ public class ReplaceWidget extends SimpleContainer {
 		horiz.add(firstArg, new BoxLayoutData(new Margins(0)));
 		horiz.add(secondArg, new BoxLayoutData(new Margins(0)));
 		horiz.setItemId(itemIdHoriz);
-		vert.add(horiz, new VerticalLayoutData(-1, -1, new Margins(1)));
+		vert.add(horiz, new VerticalLayoutData(1, -1, new Margins(1)));
 
 		firstArg.setVisible(true);
 		secondArg.setVisible(false);
@@ -1083,7 +1086,7 @@ public class ReplaceWidget extends SimpleContainer {
 
 					}
 
-					readableExpLeaf = mapReplace.getReadableExpression();
+					readableExpLeaf = expLeaf.getReadableExpression();
 				}
 
 				index++;
@@ -1136,7 +1139,7 @@ public class ReplaceWidget extends SimpleContainer {
 							break;
 
 						}
-						readableExp = mapReplace.getReadableExpression();
+						readableExp = exp.getReadableExpression();
 						expressionContainer = new ExpressionContainer(exp,
 								readableExp);
 					}
@@ -1203,7 +1206,7 @@ public class ReplaceWidget extends SimpleContainer {
 
 						}
 
-						readableExpLeaf = mapReplace.getReadableExpression();
+						readableExpLeaf = expLeaf.getReadableExpression();
 					}
 
 					index++;
@@ -1258,7 +1261,7 @@ public class ReplaceWidget extends SimpleContainer {
 								break;
 
 							}
-							readableExp = mapReplace.getReadableExpression();
+							readableExp = exp.getReadableExpression();
 							expressionContainer = new ExpressionContainer(exp,
 									readableExp);
 						}
@@ -1301,7 +1304,7 @@ public class ReplaceWidget extends SimpleContainer {
 						break;
 
 					}
-					readableExp = mapReplace.getReadableExpression();
+					readableExp = exp.getReadableExpression();
 					expressionContainer = new ExpressionContainer(exp,
 							readableExp);
 				}
